@@ -3,7 +3,7 @@ from ._version import get_versions
 from .errors import RateLimitExceeded
 from .extension import Limiter, HEADERS
 
-__version__ = get_versions()['version']
+__version__ = get_versions()["version"]
 del get_versions
 
-__all__ = ['RateLimitExceeded', 'Limiter', 'HEADERS']
+__all__ = ["RateLimitExceeded", "Limiter", "HEADERS"]
