@@ -501,7 +501,7 @@ class Limiter(object):
         if (
             not request.endpoint
             or not (self.enabled and self.initialized)
-            or view_func == current_app.send_static_file
+            or request.endpoint == "static"
             or name in self._exempt_routes
             or request.blueprint in self._blueprint_exempt
             or any(fn() for fn in self._request_filters)
@@ -702,7 +702,7 @@ class Limiter(object):
                     ):
                         self.__check_request_limit(False)
                         setattr(g, "%s_rate_limiting_complete" % self._key_prefix, True)
-                    return obj(*a, **k)
+                    return current_app.ensure_sync(obj)(*a, **k)
 
                 return __inner
 
@@ -803,7 +803,7 @@ class Limiter(object):
 
             @wraps(obj)
             def __inner(*a, **k):
-                return obj(*a, **k)
+                return current_app.ensure_sync(obj)(*a, **k)
 
             self._exempt_routes.add(name)
             return __inner
